@@ -23,6 +23,11 @@ from svc_infra.api.fastapi.auth.policy import AuthPolicy, DefaultAuthPolicy
 from svc_infra.api.fastapi.auth.settings import get_auth_settings, parse_redirect_allow_hosts
 from svc_infra.api.fastapi.db.sql.session import SqlSessionDep
 from svc_infra.api.fastapi.dual.public import public_router
+from svc_infra.api.fastapi.paths.auth import (
+    OAUTH_CALLBACK_PATH,
+    OAUTH_LOGIN_PATH,
+    OAUTH_REFRESH_PATH,
+)
 
 
 def _gen_pkce_pair() -> tuple[str, str]:
@@ -507,7 +512,6 @@ def oauth_router_with_backend(
     auth_backend: AuthenticationBackend,
     providers: Dict[str, Dict[str, Any]],
     post_login_redirect: str = "/",
-    prefix: str = "/auth/oauth",
     provider_account_model: type | None = None,
     auth_policy: AuthPolicy | None = None,
 ) -> APIRouter:
@@ -516,7 +520,6 @@ def oauth_router_with_backend(
         auth_backend,
         providers,
         post_login_redirect,
-        prefix,
         provider_account_model,
         auth_policy,
     )
@@ -527,7 +530,6 @@ def _create_oauth_router(
     auth_backend: AuthenticationBackend,
     providers: Dict[str, Dict[str, Any]],
     post_login_redirect: str = "/",
-    prefix: str = "/auth/oauth",
     provider_account_model: type | None = None,
     auth_policy: AuthPolicy | None = None,
 ) -> APIRouter:
@@ -538,10 +540,10 @@ def _create_oauth_router(
     # Register all providers
     _register_oauth_providers(oauth, providers)
 
-    router = public_router(prefix=prefix, tags=["auth:oauth"])
+    router = public_router()
 
     @router.get(
-        "/{provider}/login",
+        OAUTH_LOGIN_PATH,
         description="Login with OAuth provider",
     )
     async def oauth_login(request: Request, provider: str):
@@ -574,7 +576,7 @@ def _create_oauth_router(
         )
 
     @router.get(
-        "/{provider}/callback",
+        OAUTH_CALLBACK_PATH,
         name="oauth_callback",
         responses={302: {"description": "Redirect to app (or MFA redirect)."}},
         description="OAuth callback endpoint.",
@@ -656,7 +658,7 @@ def _create_oauth_router(
         return resp
 
     @router.post(
-        "/refresh",
+        OAUTH_REFRESH_PATH,
         status_code=status.HTTP_204_NO_CONTENT,
         responses={204: {"description": "Cookie refreshed"}},
         description="Refresh authentication token.",
