@@ -97,6 +97,7 @@ def _build_child_app(service: ServiceInfo, spec: APIVersionSpec) -> FastAPI:
 
     child.add_middleware(CatchAllExceptionMiddleware)
     register_error_handlers(child)
+    _add_route_logger(child)
 
     # ---- OpenAPI pipeline (DRY!) ----
     include_api_key = bool(spec.include_api_key) if spec.include_api_key is not None else False
@@ -149,6 +150,7 @@ def _build_parent_app(
     _setup_cors(parent, public_cors_origins)
     parent.add_middleware(CatchAllExceptionMiddleware)
     register_error_handlers(parent)
+    _add_route_logger(parent)
 
     mutators = setup_mutators(
         service=service,
@@ -172,6 +174,20 @@ def _build_parent_app(
     return parent
 
 
+def _add_route_logger(app: FastAPI):
+    @app.middleware("http")
+    async def _log_route(request, call_next):
+        resp = await call_next(request)
+        route = request.scope.get("route")
+        # Prefer FastAPI's path_format (shows param patterns), fall back to path
+        path = getattr(route, "path_format", None) or getattr(route, "path", None)
+        if path:
+            # Include mount root_path so mounted children show their full path
+            root_path = request.scope.get("root_path", "") or ""
+            resp.headers["X-Handled-By"] = f"{request.method} {root_path}{path}"
+        return resp
+
+
 def setup_service_api(
     *,
     service: ServiceInfo,
